@@ -19,7 +19,8 @@ import (
 )
 
 var (
-	silent bool
+	silent   bool
+	noPrompt bool
 )
 
 type OAuth2Cmd struct {
@@ -71,9 +72,11 @@ func NewOAuth2Cmd() (cmd *OAuth2Cmd) {
 	cmd.PersistentFlags().StringVar(&cconfig.TLSCert, "tls-cert", "", "path to tls cert pem file")
 	cmd.PersistentFlags().StringVar(&cconfig.TLSKey, "tls-key", "", "path to tls key pem file")
 	cmd.PersistentFlags().StringVar(&cconfig.TLSRootCA, "tls-root-ca", "", "path to tls root ca pem file")
-	cmd.PersistentFlags().DurationVar(&cconfig.Timeout, "timeout", time.Minute, "http client timeout")
+	cmd.PersistentFlags().DurationVar(&cconfig.HTTPTimeout, "http-timeout", time.Minute, "http client timeout")
+	cmd.PersistentFlags().DurationVar(&cconfig.BrowserTimeout, "browser-timeout", 10*time.Minute, "browser timeout")
 	cmd.PersistentFlags().BoolVar(&cconfig.Insecure, "insecure", false, "allow insecure connections")
 	cmd.PersistentFlags().BoolVarP(&silent, "silent", "s", false, "silent mode")
+	cmd.PersistentFlags().BoolVar(&noPrompt, "no-prompt", false, "disable prompt")
 	cmd.PersistentFlags().BoolVar(&cconfig.DPoP, "dpop", false, "use DPoP")
 	cmd.PersistentFlags().StringVar(&cconfig.Claims, "claims", "", "use claims")
 	cmd.PersistentFlags().StringVar(&cconfig.RAR, "rar", "", "use rich authorization request (RAR)")
@@ -107,6 +110,8 @@ func (c *OAuth2Cmd) Run(cconfig *oauth2.ClientConfig) func(cmd *cobra.Command, a
 
 		if silent {
 			browser.Stdout = io.Discard
+		} else {
+			browser.Stdout = os.Stderr
 		}
 
 		tr := &http.Transport{
@@ -117,7 +122,7 @@ func (c *OAuth2Cmd) Run(cconfig *oauth2.ClientConfig) func(cmd *cobra.Command, a
 			},
 		}
 
-		hc := &http.Client{Timeout: cconfig.Timeout, Transport: tr}
+		hc := &http.Client{Timeout: cconfig.HTTPTimeout, Transport: tr}
 
 		if cconfig.TLSCert != "" && cconfig.TLSKey != "" {
 			if cert, err = oauth2.ReadKeyPair(cconfig.TLSCert, cconfig.TLSKey, hc); err != nil {
@@ -168,7 +173,7 @@ func (c *OAuth2Cmd) Authorize(clientConfig oauth2.ClientConfig, hc *http.Client)
 		return err
 	}
 
-	if !silent {
+	if !silent && !noPrompt {
 		clientConfig = PromptForClientConfig(clientConfig, serverConfig)
 	}
 
@@ -197,10 +202,6 @@ func (c *OAuth2Cmd) Authorize(clientConfig oauth2.ClientConfig, hc *http.Client)
 }
 
 func (c *OAuth2Cmd) PrintResult(result interface{}) {
-	if !silent {
-		return
-	}
-
 	output, err := json.Marshal(result)
 
 	if err != nil {
